/*********************************************************************
 * @author Fco. Javier Rodriguez Navarro   www.pinguytaz.net
 * 
 * @version V1 Oct. 2016
 *    
 * Libreria para la gestión de los motores paso a paso UNIPOLARES
 * 
 * DATOS ALMACENAMIENTO:      
 * Clase 918 bytes  V. Globales 167 bytes
 *********************************************************************/
 
#ifndef MPaP_h
#define MPaP_h
#include <Arduino.h> //Librerias de Arduino.

// Tipos de movimientos del motor
#define NORMAL 0   //  Avance un paso con dos bobinas, alto torque y retención.
#define WAVE 1   //  Avance un paso con una bobina.
#define MEDIO 2   //  Avance medio paso, algunos con dos bobinas y otros con una.

class MPaP
{
   public: 
      MPaP(int, int, int, int); // Constructor todo por defecto, menos borna
      MPaP(int, int, int, int, int); // Añade pasos por vuelta
      
      
       ~MPaP();   // Destructor
      void avanza(void);
      void avanza(int);
      void retrocede(void);
      void retrocede(int);
      void angulo_a(float);
      void angulo_r(float);
      
      void put_secuencia(int);
      int get_secuencia(void) ;
      void put_pasos(int);
      int get_pasos(void) ;
      float put_rpm(float);
      float put_rpm();
      float get_rpm(void) ;
      void put_pps(int);
      int get_pps(void) ;
      void put_angulo(float);
      float get_angulo(void) ;
      void put_pvuelta(int);
      int get_pvuelta(void) ;


   private:
      int secuencia = NORMAL;        // Tipo de secuencia en el que se activan las bobinas, ya sea para los unipolares. 
      int BOB_A, BOB_B, BOB_C, BOB_D;   //Pines a los que se conectan las bobinas del motor.
      int paso;       // Indica el paso de secuencia por el que va..
      int pasos=1;     // Indica los pasos que recorre en un avance.
      boolean sec_NORMAL[4][4] = {{1,1,0,0},{0,1,1,0},{0,0,1,1},{1,0,0,1}};
      boolean sec_WAVE[4][4] =   {{1,0,0,0}, {0,1,0,0},{0,0,1,0},{0,0,0,1}};
      boolean sec_MEDIO[8][4]=   {{1,0,0,0},{1,1,0,0},{0,1,0,0},{0,1,1,0},{0,0,1,0},{0,0,1,1},{0,0,0,1},{1,0,0,1}};
        
      int pps=200;      // indica los pasos por segundos maximos que aguanta el motor
      float angulo=18; // angulo que gira en un paso = 360/pasos en una vuelta.
      int pvuelta=360/angulo; // Pasos por vuelta = 360/angulo
      float max_rpm=pps*60/pvuelta;;  // Velocidad maxima a alcanzar
      float rpm=max_rpm;

      void avanza_uno(void);
      void retrocede_uno(void);
      void activa(void);
      int cpasos(float);
      void asignapines(int a, int b, int c, int d);
};

#endif


